@@ -3,7 +3,7 @@
 """This module provides classes related to RBAC users in the PCE.
 
 Copyright:
-    (c) 2022 Illumio
+    © 2022 Illumio
 
 License:
     Apache2, see LICENSE for more details.
@@ -16,6 +16,7 @@ from illumio.util import IllumioObject, pce_api
 @dataclass
 @pce_api('users', is_global=True)
 class User(IllumioObject):
+    """Represents a user object in the PCE."""
     username: str = None
     last_login_on: str = None
     last_login_ip_address: str = None
@@ -27,3 +28,8 @@ class User(IllumioObject):
     local_profile: dict = None
     type: str = None
     presence_status: str = None
+
+
+__all__ = [
+    'User',
+]
