@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 
-"""
+"""This module provides classes related to traffic analysis and the PCE Explorer.
+
 Copyright:
-    (c) 2022 Illumio
+    © 2022 Illumio
 
 License:
     Apache2, see LICENSE for more details.
