@@ -3,7 +3,7 @@
 """This module provides classes related to pairing profile objects.
 
 Copyright:
-    (c) 2022 Illumio
+    © 2022 Illumio
 
 License:
     Apache2, see LICENSE for more details.
@@ -29,15 +29,19 @@ class PairingProfile(MutableObject):
     Pairing profiles are used to configure VEN defaults and generate keys
     for VEN pairing  on workloads that will be managed by the PCE.
 
+    See https://docs.illumio.com/asp/20.1/Content/Guides/rest-api/workloads/pairing-profiles-and-pairing-keys.htm
+
     Usage:
-        >>> from illumio.workloads import PairingProfile
-        >>> pairing_profile = PairingProfile(
+        >>> import illumio
+        >>> pce = illumio.PolicyComputeEngine('pce.company.com', port=443, org_id=1)
+        >>> pce.set_credentials('api_key', 'api_secret')
+        >>> pairing_profile = illumio.PairingProfile(
         ...     name='PP-DATABASE-VENS',
         ...     enabled=True,
         ...     enforcement_mode='visibility_only',
         ...     visibility_level='flows_summary'
         ... )
-        >>> pairing_profile = pce.create_pairing_profile(pairing_profile)
+        >>> pairing_profile = pce.pairing_profiles.create(pairing_profile)
         >>> pairing_profile
         PairingProfile(
             href='/orgs/1/pairing_profiles/19',
@@ -89,3 +93,8 @@ class PairingProfile(MutableObject):
                 value = int(value)
             return value
         return super()._encode_field(field)
+
+
+__all__ = [
+    'PairingProfile',
+]
